phoneapp/phoneuicontrol/inc/cphonestate.h
branchRCL_3
changeset 25 91c2fb4b78df
parent 15 2a26698d78ba
child 31 ba54057fe027
--- a/phoneapp/phoneuicontrol/inc/cphonestate.h	Wed Apr 14 15:56:42 2010 +0300
+++ b/phoneapp/phoneuicontrol/inc/cphonestate.h	Tue Apr 27 16:37:10 2010 +0300
@@ -42,6 +42,10 @@
 enum TStateTransEffectType
     {
     ENoneType,
+    // These effect types can be used only when NE is opened/closed
+    // when some other app than phone is visible on the foreground/
+    // background.
+    // These cannot be used for internal transitions (=call ui<->dialer).
     ENumberEntryOpen,
     ENumberEntryClose,
     ENumberEntryCreate
@@ -242,7 +246,8 @@
         IMPORT_C void HandleLongHashL();
 
         /**
         * Informs view to start Transition effect
         * @param aType a transition effect, default none
         * EndTransEffect() must be called when update is done.
         */
@@ -615,6 +620,14 @@
         */
         IMPORT_C virtual void OnlyHashInNumberEntryL();
 
+        /*
+        * Checks if it's ok to use aType effect in this state.
+        *
+        * @param aType effect to be checked
+        * @return true if aType effect can be used
+        */
+        IMPORT_C virtual TBool CanTransEffectTypeBeUsed( TStateTransEffectType aType );
+
         /**
         * Informs view that UI is being updated (call bubble or number editor).
         * EndUiUpdate() must be called when update is done.
@@ -711,6 +724,7 @@
         * Returns customized dialer CBA resource id
         */
         IMPORT_C TInt CustomizedDialerCbaResourceIdL();
+        
 
     protected: // NumberEntry functions.
@@ -242,7 +246,8 @@
 
         /**
-        * Informs view to start Transition effect
+        * Informs view to start Transition effect if effect
+        * type is feasible for current state.
         * @param aType a transition effect, default none
         * EndTransEffect() must be called when update is done.